// filedir.cpp : File and directory manipulation functions.
//
// Includes the following functions:
//		
//		
//
//

#include "stdafx.h"
#include "filedir.h"



//char msg[512];
//wsprintf(msg, "%d, File: %s\nRoot: %s\nFound: %s", nResult, pszFileName, szRootDir, retFoundPath);
//MessageBox( 0, sPathFile, "Full Path and File", MB_OK );
/////////////////////////////////////////////////////////////////////////////
//IsFile
//  Checks to see if a file exists. If it's a full path and file name,
//  only that path and file name are checked. If it's onlya file name,
//  the current folder is used.
//

/////////////////////////////////////////////////////////////////////////////
int IsFile( LPCSTR sFile )
{
	int success;
	char retval[1024];
	CString cBackslash = "\\";
	CString cFile = sFile;
	CString sPathFile;

	//Get the instance handle for the DLL
	CWinApp* theApp = AfxGetApp();
	HINSTANCE dllInstance = theApp->m_hInstance;
	//Get the path and file name of the DLL
	success = GetModuleFileName(dllInstance, retval, 256);
	if (success == 0)
	{  //Failure getting DLL name
		return FALSE;
	}
	CString dllPath = retval;

	sPathFile = GetFullFileSpec ( cFile, dllPath );

	//Now see if the file exists.
	CFileFind finder;
	BOOL bWorking = finder.FindFile( sPathFile );
	finder.Close();
	if ( bWorking == TRUE )
	{	//File was found.
		return 1;
	}
	else
	{	//File was not found.
		return 0;
	}
}


/////////////////////////////////////////////////////////////////////////////
//GetParentFolder
//
//	Strips one level of folder off the path. Assumes no file is included,
//		so if you give it a full path and file name, you get the folder
//		in which the file resides (which is, after all, the parent folder
//		of the file).
//
//Parameters:
//	LPCSTR sPath	Points to a null-terminated string containing the path.
//
//Return:
//	The parent folder.
//
/////////////////////////////////////////////////////////////////////////////
CString GetParentFolder ( LPCSTR sPath )
{
	CString cBackslash = "\\";
	CString cPath = sPath;

	//If the last character is a slash or backslash, eliminate it.
	if ( cPath.Right(1) == "\\" || cPath.Right(1) == "/" )
	{
		cPath = cPath.Left( cPath.GetLength() - 1 );
	}

	//Find the last slash  and the last backslash.
	int backSlash = cPath.ReverseFind( cBackslash.GetAt(0) );
	int forwardSlash = cPath.ReverseFind('/');
	if ( backSlash < 0 && forwardSlash < 0 )
	{	//No slashes found. Just return what we got.
		return cPath;
	}

	//Use whichever of the slash or backslash is the last one in the string.
	if ( forwardSlash > backSlash )
	{
		backSlash = forwardSlash;
	}

	if ( backSlash > 0 )
	{	//Truncate the string to the parent folder.
		cPath = cPath.Left( backSlash );
	}

	return cPath;
}



//****************************************************************************
//	ChangeExtension
//
//		Changes the extension of a file to the specified extension
//
//	Parameters:
//
//	LPSTR cFile				Points to a null-terminated string containing the
//							current file name.
//	LPSTR cExtension		Points to a null-terminated string containing the
//							new extension.
//	LPSTR cNewFile			Points to a null-turminated string containing a file
//							name with the new value.							
//
//	Return value
//		BOOL				Always returns 1--doesn't really tell you anything.
//
//****************************************************************************
BOOL ChangeExtension (LPSTR cFile, LPSTR cExtension, LPSTR cNewFile)
{
	int success;
	int  ch = 46;
	LPSTR pdest;
	LPSTR lpSuccess;
	char dExtension[256];
	char string[256];

	pdest = strrchr( cExtension, ch );  //Does new extension have a dot?
 	if( pdest == NULL )	  //No dot found. Add to front of new extension.
 		{
		pdest = lstrcpy(dExtension, ".");  //Write a dot
		lpSuccess = lstrcat(dExtension, cExtension);  //Append the extension
		}
    else    //Dot found. Just copy the new extension.
		pdest = lstrcpy(dExtension, cExtension);
    
	pdest = lstrcpy(string, cFile);  //Copy the file name (don't destroy original)
	pdest = strrchr( string, ch );  //Does file have an extension?
	if( pdest != NULL )  //Extension found
	{
    	*(pdest) = '\0';   //Replace dot with NULL (strip old extension).
	}

	//Add new extension.
	lpSuccess = lstrcat(string, dExtension);  //Append new extension

	//Make lower case and return the new string
	success = wsprintf(cNewFile, "%s", _strlwr( _strdup( string ) ) );
	
	return 1;
}


//****************************************************************************
//	GetNameOnly
//
//		Gets the name (no path) of the executable--without its extension.
//
//	Parameters:
//
//	LPSTR cFile				Points to a null-terminated string containing the
//							file name, with or without a path.
//	LPSTR cNewFile			Points to a null-turminated string containing a file
//							name with the new value.							
//
//	Return value
//		BOOL				Always returns 1--doesn't really tell you anything.
//
//****************************************************************************
BOOL GetNameOnly (LPSTR cFile, LPSTR cNewFile)
{
	int success;
	int  ch;
	LPSTR pdest;
	char string[256];

	pdest = lstrcpy(string, cFile);  //Copy the file name (don't destroy original)
	
	//Remove the extension (if any)
	ch = 46;   //"."
	pdest = strrchr( string, ch );  //Does file have a dot?
	if( pdest != NULL )  //Dot found. There is an extension
	{
    	*(pdest) = '\0';   //Write NULL to character to replace dot (strip extension)
	}

	//Remove path (if any)
	ch=92;   //"\"
	pdest = strrchr( string, ch );  //Find the last backslash (if any)
	if (pdest == NULL)   //No path found. Return the whole string.
	{
		success = wsprintf(cNewFile, "%s", _strlwr( _strdup( string ) ) );   //Lower case
	}
	else    //Path found. Return only after the last backslash.
	{
		success = wsprintf(cNewFile, "%s", _strlwr( _strdup( pdest + 1 ) ) );   //Lower case
	}

	return 1;
}



//****************************************************************************
//GetFullFileSpec
//
//	Checks to see if there is a full path (including drive) on a filespec.
//		If not, adds the path from the sPath variable.
//
//Parameters:
//	LPCSTR sFile points to a CString object containing the file, and if necessary,
//		a relative path. If a full path shows up, it is used intact.
//							if necessary, and the name of a file.
//	LPCSTR sPath points to a full path *and* file name containing the
//		default path you want to add if cFile doesn't
//		contain a full path (i.e., no drive spec).
//
//Return value:
//	CString cPathFile points to a CStrign object containing a full path and
//		file name to use.
//
//****************************************************************************
CString GetFullFileSpec ( LPCSTR sFile, LPCSTR sPath )
{
	CString cColon = ':';
	CString cBackslash = "\\";
	CString cPathFile;
	CString cPath = sPath;
	CString cFile = sFile;

	//If the last character is a slash or backslash, eliminate it.
	if ( cPath.Right(1) == "\\" || cPath.Right(1) == "/" )
	{	//This is a path only.
		cPath = cPath.Left( cPath.GetLength() - 1 );
	}
	else
	{	//This is a file and path. Eliminate the file.
		cPath = GetParentFolder( cPath );
	}

	//See if the file name is a full path.
	int colonLoc = cFile.Find( cColon );
	if ( colonLoc == 0 )
	{	//Colon not found. This is a relative path or file only.
		cPathFile = cPath + "\\";
		cPathFile = cPathFile + cFile;
	}
	else
	{	//Colon found. This is a full file and path. Use as is.
		cPathFile = cFile;
	}
	
	return cPathFile;
}
