#include "stdafx.h"
#include "UseRegInfo.h"

#include "FileDir.h"

//////////////////////////////////////////////////////////////////////
//GetPersistentString
//	Get a string value from the HKEY_CURRENT_USER section of the Registry
//
//
//////////////////////////////////////////////////////////////////////
CString GetPersistentString ( LPCTSTR Section, LPCTSTR Variable,  LPCTSTR Default) 
{
	HKEY  hKey1,hKey2;
	LONG  lRetCode1;
	LONG	lRetCode2 = -1;
	LONG	lRetCode3 = -1;
	LONG	lRetCode4 = -1;
	unsigned char* Buffer;
	unsigned long length;
 
	// Open the S20 file key
	lRetCode1 = RegOpenKeyEx ( HKEY_CURRENT_USER, RegIniKey, 0, KEY_QUERY_VALUE, &hKey1);

	// Open the section key
    if (lRetCode1 == ERROR_SUCCESS)
	{
		lRetCode2 = RegOpenKeyEx ( hKey1, Section, 0, KEY_QUERY_VALUE, &hKey2);
	}

	//check the length of the value
	if (lRetCode2 == ERROR_SUCCESS)
	{
		lRetCode3 = RegQueryInfoKey ( hKey2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, &length, NULL, NULL);
	}

	if (lRetCode3 == ERROR_SUCCESS)
	{
		Buffer = new unsigned char [length];
	}
	else
	{
		Buffer = new unsigned char [256]; //default
	}

	//get variable
	if (lRetCode2 == ERROR_SUCCESS)
	{
		lRetCode4 = RegQueryValueEx ( hKey2, Variable, NULL, NULL, Buffer, &length);
	}

	CString Value(Buffer);

	if (lRetCode1 != ERROR_SUCCESS || lRetCode2 != ERROR_SUCCESS || lRetCode3 != ERROR_SUCCESS || lRetCode4 != ERROR_SUCCESS)
	{
		Value = Default;
	}

	if (lRetCode1 == ERROR_SUCCESS)
	{
		RegCloseKey(hKey1);
	}

	if (lRetCode2 == ERROR_SUCCESS)
	{
		RegCloseKey(hKey2);
	}

	delete Buffer;
	return Value;
}




//////////////////////////////////////////////////////////////////////
//GetPersistentInteger
//	Get an integer value from the HKEY_CURRENT_USER section of the Registry.
//
//
//////////////////////////////////////////////////////////////////////
int GetPersistentInteger ( LPCTSTR Section, LPCTSTR Variable, int Default) 
{
	HKEY  hKey1,hKey2; 
	LONG   lRetCode; 

	// Open the file key
	lRetCode = RegOpenKeyEx ( HKEY_CURRENT_USER, RegIniKey, 0, KEY_QUERY_VALUE, &hKey1);

	// Open the section key
	lRetCode = RegOpenKeyEx ( hKey1, Section, 0, KEY_QUERY_VALUE, &hKey2);

	unsigned char Buffer[200];
	int RegValue;
	unsigned long length = 200;
	//get variable
	lRetCode = RegQueryValueEx ( hKey2, Variable, NULL, NULL, Buffer, &length);

	if (lRetCode != ERROR_SUCCESS)
	{
		RegValue = Default;
	}
	else
	{
		RegValue=atoi((char*)&Buffer[0]);
	}

	RegCloseKey(hKey1);
	RegCloseKey(hKey2);

	return RegValue;
}



//////////////////////////////////////////////////////////////////////
//WritePersistentString
//	Write a string value to the HKEY_CURRENT_USER section of the Registry.
//
//
//////////////////////////////////////////////////////////////////////
void WritePersistentString (CString Section, CString Variable, CString Value)
{
	HKEY  hKey1,hKey2;
	DWORD dwDisposition;
	LONG  lRetCode1;
	LONG	lRetCode2 = -1;
	LONG	lRetCode3 = -1;

	// Create the key; if key exists, open it
	lRetCode1 = RegCreateKeyEx ( HKEY_CURRENT_USER, RegIniKey, 0, NULL, REG_OPTION_NON_VOLATILE, KEY_WRITE, NULL, &hKey1, &dwDisposition);

	// Create the section key; if key exists, open it
	if (lRetCode1 == ERROR_SUCCESS)
	{
	  lRetCode2 = RegCreateKeyEx ( hKey1, Section, 0, NULL, REG_OPTION_NON_VOLATILE, KEY_WRITE, NULL, &hKey2, &dwDisposition);
	}

	// Set the variable value
	if (lRetCode2 == ERROR_SUCCESS)
	{
		lRetCode3 = RegSetValueEx ( hKey2, Variable, 0, REG_SZ, (unsigned char*)(Value.GetBuffer(Value.GetLength())), Value.GetLength()+1);    // +1 for NULL terminator char
	}

	if (lRetCode1 == ERROR_SUCCESS)
	{
		RegCloseKey(hKey1);
	}

	if (lRetCode2 == ERROR_SUCCESS)
	{
		RegCloseKey(hKey2);
	}
}



//////////////////////////////////////////////////////////////////////
//PutHelpFileRegEntry
//	Writes a String value to the registry in the Help file registration area.
//
//Parameters:
//	cHelpFile is the name of the Help file, includint the extension.
//		You can register help and contents files in this area.
//	cHelpFileFolder is the folder where WinHelp can find the specified
//		Help file.
//
//Return: None
//
//////////////////////////////////////////////////////////////////////
void PutHelpFileRegEntry ( LPCTSTR cHelpFile, CString cHelpFileFolder )
{

	HKEY  hKey1,hKey2; 
	DWORD  dwDisposition; 
	LONG   lRetCode; 
	CString cRegistryPath = "software\\microsoft\\windows";

	// Create the S20 file key; if key exists, open it
	lRetCode = RegCreateKeyEx ( HKEY_LOCAL_MACHINE, cRegistryPath, 0, NULL, REG_OPTION_NON_VOLATILE, KEY_WRITE, NULL, &hKey1, &dwDisposition);

	// Create the section key; if key exists, open it
	lRetCode = RegCreateKeyEx ( hKey1, "help", 0, NULL, REG_OPTION_NON_VOLATILE, KEY_WRITE, NULL, &hKey2, &dwDisposition);

	// Set the variable value 
	lRetCode = RegSetValueEx ( hKey2, cHelpFile, 0, REG_SZ, (unsigned char*)(cHelpFileFolder.GetBuffer(200)), 20); 

}



//////////////////////////////////////////////////////////////////////
//GetHelpFileLocation
//	Get the location of the specified Help file from the registry.
//
//Parameters:
//	Variable is the name of the Help file to search for.
//
//Return: The folder where you should be able to find the Help file.
//
//////////////////////////////////////////////////////////////////////
CString GetHelpFileLocation ( LPCTSTR Variable ) 
{
	HKEY  hKey1,hKey2;
	LONG  lRetCode1;
	LONG	lRetCode2 = -1;
	LONG	lRetCode3 = -1;
	LONG	lRetCode4 = -1;
	unsigned char* Buffer;
	unsigned long length;
 
	// Open the S20 file key
	lRetCode1 = RegOpenKeyEx ( HKEY_LOCAL_MACHINE, "software\\microsoft\\windows", 0, KEY_QUERY_VALUE, &hKey1);

	// Open the section key
    if (lRetCode1 == ERROR_SUCCESS)
	{
		lRetCode2 = RegOpenKeyEx ( hKey1, "Help", 0, KEY_QUERY_VALUE, &hKey2);
	}

	//check the length of the value
	if (lRetCode2 == ERROR_SUCCESS)
	{
		lRetCode3 = RegQueryInfoKey ( hKey2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, &length, NULL, NULL);
	}

	if (lRetCode3 == ERROR_SUCCESS)
	{
		Buffer = new unsigned char [length];
	}
	else
	{
		Buffer = new unsigned char [256]; //default
	}

	//get variable
	if (lRetCode2 == ERROR_SUCCESS)
	{
		lRetCode4 = RegQueryValueEx ( hKey2, Variable, NULL, NULL, Buffer, &length);
	}

	CString Value(Buffer);

	if (lRetCode1 != ERROR_SUCCESS || lRetCode2 != ERROR_SUCCESS || lRetCode3 != ERROR_SUCCESS || lRetCode4 != ERROR_SUCCESS)
	{
		Value = "";
	}

	if (lRetCode1 == ERROR_SUCCESS)
	{
		RegCloseKey(hKey1);
	}

	if (lRetCode2 == ERROR_SUCCESS)
	{
		RegCloseKey(hKey2);
	}

	delete Buffer;

	CString sTestHelpFile = Value + "\\" + Variable;
	CFileFind finder;
	BOOL bWorking = finder.FindFile( sTestHelpFile );
	finder.Close();
	if ( bWorking == TRUE )
	{	//File was found. Return the folder.
		return Value;
	}
	else
	{	//File was not found. Return empty string.
		return "";
	}
}



//////////////////////////////////////////////////////////////////////
//GetProgramLocation
//	Get a string value from the HKEY_LOCAL_MACHINE section of the Registry
//
//
//////////////////////////////////////////////////////////////////////
CString GetProgramLocation ( LPCTSTR cRegistryPath, LPCSTR cSection, LPCSTR cVariable ) 
{
	HKEY  hKey1,hKey2;
	LONG  lRetCode1;
	LONG	lRetCode2 = -1;
	LONG	lRetCode3 = -1;
	LONG	lRetCode4 = -1;
	unsigned char* Buffer;
	unsigned long length;
	//CString cRegistryPath = RegIniKey + cAppRegistrySubPath;
 
	// Open the S20 file key
	lRetCode1 = RegOpenKeyEx ( HKEY_LOCAL_MACHINE, cRegistryPath, 0, KEY_QUERY_VALUE, &hKey1);

	// Open the section key
    if (lRetCode1 == ERROR_SUCCESS)
	{
		lRetCode2 = RegOpenKeyEx ( hKey1, cSection, 0, KEY_QUERY_VALUE, &hKey2);
	}

	//check the length of the value
	if (lRetCode2 == ERROR_SUCCESS)
	{
		lRetCode3 = RegQueryInfoKey ( hKey2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, &length, NULL, NULL);
	}

	if (lRetCode3 == ERROR_SUCCESS)
	{
		Buffer = new unsigned char [length];
	}
	else
	{
		Buffer = new unsigned char [256]; //default
	}

	//get variable
	if (lRetCode2 == ERROR_SUCCESS)
	{
		lRetCode4 = RegQueryValueEx ( hKey2, cVariable, NULL, NULL, Buffer, &length);
	}

	CString Value(Buffer);

	if (lRetCode1 != ERROR_SUCCESS || lRetCode2 != ERROR_SUCCESS || lRetCode3 != ERROR_SUCCESS || lRetCode4 != ERROR_SUCCESS)
	{
		Value = "";
	}

	if (lRetCode1 == ERROR_SUCCESS)
	{
		RegCloseKey(hKey1);
	}

	if (lRetCode2 == ERROR_SUCCESS)
	{
		RegCloseKey(hKey2);
	}

	delete Buffer;
	return Value;
}
